// src/route/select.tsx
import React2, { memo as memo2 } from "react";

// src/common/routeHooks.ts
import { useSearchParams } from "react-router-dom";
function useRouteSelect(options, filterName, defaultValues = []) {
  const [searchParams, setSearchParams] = useSearchParams();
  const optionValues = searchParams.getAll(filterName);
  const selectedValues = optionValues.length > 0 ? optionValues : defaultValues;
  const selectedOptions = selectedValues.length > 0 ? options.filter((x) => selectedValues.includes(x.value)) : [];
  const onChange = (option) => {
    searchParams.delete(filterName);
    const values = Array.isArray(option) ? option.map((x) => x.value) : [option?.value || ""];
    values.forEach((value) => {
      if (!defaultValues.includes(value)) {
        searchParams.append(filterName, value);
      }
    });
    setSearchParams(searchParams, { replace: true });
  };
  return {
    optionValues,
    selectedOptions,
    onChange
  };
}

// src/select.tsx
import classNames from "classnames";
import React, { Fragment, memo } from "react";
import { Listbox, Transition } from "@headlessui/react";
import {
  CheckIcon,
  ChevronDownIcon,
  XMarkIcon
} from "@heroicons/react/20/solid";
function Select({
  className,
  options,
  selectedOption,
  selectedOptions,
  onChange,
  multiple,
  placeholder,
  isLoading,
  filter,
  resetButton = true
}) {
  const selectedValue = multiple ? selectedOptions : selectedOption;
  const selectedLabel = multiple ? selectedOptions?.map((x) => x.label).join(", ") : selectedOption?.label;
  return /* @__PURE__ */ React.createElement(
    Listbox,
    {
      value: selectedValue || null,
      onChange,
      multiple,
      as: "div",
      className: classNames("relative", className)
    },
    /* @__PURE__ */ React.createElement(
      Listbox.Button,
      {
        className: classNames(
          "form-input relative w-full cursor-default pl-3 pr-10 text-left",
          filter ? "form-input-filter" : ""
        )
      },
      /* @__PURE__ */ React.createElement(
        "span",
        {
          title: selectedLabel,
          className: classNames(
            "block truncate",
            selectedLabel ? "" : "text-secondary-500"
          )
        },
        selectedLabel || placeholder
      ),
      (!resetButton || !selectedLabel) && /* @__PURE__ */ React.createElement("span", { className: "pointer-events-none absolute inset-y-0 right-2 flex items-center" }, /* @__PURE__ */ React.createElement(ChevronDownIcon, { className: "form-input-icon h-5 w-5", "aria-hidden": "true" }))
    ),
    resetButton && selectedLabel && /* @__PURE__ */ React.createElement(
      "button",
      {
        type: "button",
        className: "form-input-reset absolute z-10 right-2.5 inset-y-0 my-auto h-5 px-0.5",
        onClick: () => {
          if (multiple) {
            onChange([]);
          } else {
            onChange(null);
          }
        }
      },
      /* @__PURE__ */ React.createElement(XMarkIcon, { className: "h-4 w-4", "aria-hidden": "true" })
    ),
    /* @__PURE__ */ React.createElement(
      Transition,
      {
        as: Fragment,
        leave: "transition ease-in duration-100",
        leaveFrom: "opacity-100",
        leaveTo: "opacity-0"
      },
      /* @__PURE__ */ React.createElement(Listbox.Options, { className: "form-input-popup absolute z-40 mt-1 w-full bg-white py-1 shadow-lg ring-1 ring-black ring-opacity-5 focus:outline-none text-sm" }, options.length === 0 || isLoading ? /* @__PURE__ */ React.createElement("div", { className: "relative cursor-default select-none py-2 px-4 text-secondary-700" }, isLoading ? "Loading..." : "No options") : /* @__PURE__ */ React.createElement("div", { className: "overflow-auto max-h-60" }, options.map((option) => /* @__PURE__ */ React.createElement(
        Listbox.Option,
        {
          key: option.label,
          className: ({ active }) => `relative cursor-default select-none py-2 pl-10 pr-4 text-secondary-800 ${active ? "bg-primary-100" : ""}`,
          value: option
        },
        ({ selected }) => /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(
          "span",
          {
            title: option.label,
            className: `block truncate ${selected && selectedValue ? "font-medium text-secondary-900" : "font-normal"}`
          },
          option.label
        ), selected && selectedValue ? /* @__PURE__ */ React.createElement("span", { className: "absolute inset-y-0 left-0 flex items-center pl-3 text-primary-600" }, /* @__PURE__ */ React.createElement(CheckIcon, { className: "h-5 w-5", "aria-hidden": "true" })) : null)
      ))))
    )
  );
}
var select_default = memo(Select);

// src/route/select.tsx
function RouteSelect({
  options,
  filterName,
  multiple,
  filter,
  defaultValue = "",
  defaultValues = [""],
  ...rest
}) {
  const { onChange, selectedOptions, optionValues } = useRouteSelect(
    options,
    filterName,
    multiple ? defaultValues : [defaultValue]
  );
  if (multiple) {
    return /* @__PURE__ */ React2.createElement(
      select_default,
      {
        ...rest,
        options,
        selectedOptions,
        onChange,
        multiple: true,
        filter: filter ?? optionValues.length > 0
      }
    );
  }
  return /* @__PURE__ */ React2.createElement(
    select_default,
    {
      ...rest,
      options,
      selectedOption: selectedOptions[0] || null,
      onChange,
      filter: filter ?? optionValues.length > 0
    }
  );
}
var select_default2 = memo2(RouteSelect);

// src/route/searchSelect.tsx
import React4, { memo as memo4 } from "react";

// src/searchSelect.tsx
import classNames2 from "classnames";
import React3, { Fragment as Fragment2, memo as memo3, useState } from "react";
import { Combobox, Transition as Transition2 } from "@headlessui/react";
import {
  CheckIcon as CheckIcon2,
  ChevronDownIcon as ChevronDownIcon2,
  XMarkIcon as XMarkIcon2,
  MagnifyingGlassIcon
} from "@heroicons/react/20/solid";
function SearchSelect({
  className,
  options,
  selectedOption,
  selectedOptions,
  onChange,
  multiple,
  placeholder,
  isLoading,
  filter,
  resetButton = true
}) {
  const [searchQuery, setSearchQuery] = useState("");
  const selectedValue = multiple ? selectedOptions : selectedOption;
  const selectedLabel = multiple ? selectedOptions?.map((x) => x.label).join(", ") : selectedOption?.label;
  const searchString = searchQuery.toLowerCase().replace(/\s+/g, "");
  const currentOptions = searchQuery === "" ? options : options.filter(
    (x) => x.label.toLowerCase().replace(/\s+/g, "").includes(searchString)
  );
  return /* @__PURE__ */ React3.createElement(
    Combobox,
    {
      value: selectedValue || null,
      onChange,
      multiple,
      nullable: true,
      as: "div",
      className: classNames2("relative", className)
    },
    /* @__PURE__ */ React3.createElement(Combobox.Button, { as: "div" }, /* @__PURE__ */ React3.createElement(
      "button",
      {
        type: "button",
        className: classNames2(
          "form-input relative w-full cursor-default pl-3 pr-10 text-left",
          filter ? "form-input-filter" : ""
        )
      },
      /* @__PURE__ */ React3.createElement(
        "span",
        {
          title: selectedLabel,
          className: classNames2(
            "block truncate",
            selectedLabel ? "" : "text-secondary-500"
          )
        },
        selectedLabel || placeholder
      ),
      (!resetButton || !selectedLabel) && /* @__PURE__ */ React3.createElement("span", { className: "pointer-events-none absolute inset-y-0 right-0 flex items-center pr-2" }, /* @__PURE__ */ React3.createElement(ChevronDownIcon2, { className: "form-input-icon h-5 w-5", "aria-hidden": "true" }))
    )),
    resetButton && selectedLabel && /* @__PURE__ */ React3.createElement(
      "button",
      {
        type: "button",
        className: "form-input-reset absolute z-10 right-2.5 inset-y-0 my-auto h-5 px-0.5",
        onClick: () => {
          if (multiple) {
            onChange([]);
          } else {
            onChange(null);
          }
        }
      },
      /* @__PURE__ */ React3.createElement(XMarkIcon2, { className: "h-4 w-4", "aria-hidden": "true" })
    ),
    /* @__PURE__ */ React3.createElement(
      Transition2,
      {
        as: Fragment2,
        leave: "transition ease-in duration-100",
        leaveFrom: "opacity-100",
        leaveTo: "opacity-0",
        afterLeave: () => {
          setSearchQuery("");
        }
      },
      /* @__PURE__ */ React3.createElement(Combobox.Options, { className: "form-input-popup absolute z-40 mt-1 w-full bg-white py-1 shadow-lg ring-1 ring-black ring-opacity-5 focus:outline-none text-sm" }, !isLoading && /* @__PURE__ */ React3.createElement("div", { className: "relative" }, /* @__PURE__ */ React3.createElement(
        MagnifyingGlassIcon,
        {
          className: "pointer-events-none absolute top-3.5 left-4 h-5 w-5 text-secondary-400",
          "aria-hidden": "true"
        }
      ), /* @__PURE__ */ React3.createElement(
        Combobox.Input,
        {
          type: "search",
          placeholder: "Search...",
          className: "h-12 w-full bottom-0 border-transparent pl-11 pr-4 text-secondary-800 placeholder-secondary-400 text-sm focus:border-none focus:outline-none focus:ring-0 focus:shadow-none",
          displayValue: () => searchQuery,
          onChange: (event) => {
            setSearchQuery(event.target.value);
          }
        }
      )), currentOptions.length === 0 || isLoading ? /* @__PURE__ */ React3.createElement("div", { className: "relative cursor-default select-none py-2 px-4 text-secondary-700" }, isLoading ? "Loading..." : "No options") : /* @__PURE__ */ React3.createElement("div", { className: "overflow-auto max-h-60" }, currentOptions.map((option) => /* @__PURE__ */ React3.createElement(
        Combobox.Option,
        {
          key: option.label,
          className: ({ active }) => `relative cursor-default select-none py-2 pl-10 pr-4 text-secondary-800 ${active ? "bg-primary-100" : ""}`,
          value: option
        },
        ({ selected }) => /* @__PURE__ */ React3.createElement(React3.Fragment, null, /* @__PURE__ */ React3.createElement(
          "span",
          {
            title: option.label,
            className: `block truncate ${selected && selectedValue ? "font-medium text-secondary-900" : "font-normal"}`
          },
          option.label
        ), selected && selectedValue ? /* @__PURE__ */ React3.createElement("span", { className: "absolute inset-y-0 left-0 flex items-center pl-3 text-primary-600" }, /* @__PURE__ */ React3.createElement(CheckIcon2, { className: "h-5 w-5", "aria-hidden": "true" })) : null)
      ))))
    )
  );
}
var searchSelect_default = memo3(SearchSelect);

// src/route/searchSelect.tsx
function RouteSearchSelect({
  options,
  filterName,
  defaultValue = "",
  defaultValues = [""],
  multiple,
  filter,
  ...rest
}) {
  const { onChange, selectedOptions, optionValues } = useRouteSelect(
    options,
    filterName,
    multiple ? defaultValues : [defaultValue]
  );
  if (multiple) {
    return /* @__PURE__ */ React4.createElement(
      searchSelect_default,
      {
        ...rest,
        options,
        selectedOptions,
        onChange,
        multiple: true,
        filter: filter ?? optionValues.length > 0
      }
    );
  }
  return /* @__PURE__ */ React4.createElement(
    searchSelect_default,
    {
      ...rest,
      options,
      selectedOption: selectedOptions[0] || null,
      onChange,
      filter: filter ?? optionValues.length > 0
    }
  );
}
var searchSelect_default2 = memo4(RouteSearchSelect);

// src/combobox.tsx
import React5, { memo as memo5 } from "react";
function Combobox2(props) {
  if (props.options.length > 6) {
    return /* @__PURE__ */ React5.createElement(searchSelect_default, { ...props });
  }
  return /* @__PURE__ */ React5.createElement(select_default, { ...props });
}
var combobox_default = memo5(Combobox2);

// src/route/combobox.tsx
import React6, { memo as memo6 } from "react";
function RouteCombobox(props) {
  if (props.options.length > 6) {
    return /* @__PURE__ */ React6.createElement(searchSelect_default2, { ...props });
  }
  return /* @__PURE__ */ React6.createElement(select_default2, { ...props });
}
var combobox_default2 = memo6(RouteCombobox);

// src/route/autocomplete.tsx
import React8, { memo as memo8 } from "react";

// src/autocomplete.tsx
import classNames3 from "classnames";
import React7, { Fragment as Fragment3, memo as memo7 } from "react";
import { Combobox as Combobox3, Transition as Transition3 } from "@headlessui/react";
import { CheckIcon as CheckIcon3, XMarkIcon as XMarkIcon3 } from "@heroicons/react/20/solid";
function Autocomplete({
  className,
  options,
  selectedOption,
  onChange,
  placeholder,
  isLoading,
  filter,
  searchQuery,
  onSearch,
  minQueryLength = 2,
  resetButton = true
}) {
  const selectedValue = selectedOption;
  const selectedLabel = selectedOption?.label || "";
  const emptyMessage = searchQuery.length < minQueryLength ? `Type at least ${minQueryLength} symbols` : "Nothing found";
  const showOptions = options.length > 0 && !isLoading && searchQuery.length >= minQueryLength;
  return /* @__PURE__ */ React7.createElement(
    Combobox3,
    {
      value: selectedValue,
      onChange,
      nullable: true,
      as: "div",
      className: classNames3("relative", className)
    },
    /* @__PURE__ */ React7.createElement(
      Combobox3.Input,
      {
        placeholder,
        className: classNames3(
          "form-input relative w-full cursor-default pl-3 pr-10 text-left truncate placeholder-secondary-500",
          filter ? "form-input-filter" : ""
        ),
        displayValue: () => searchQuery || selectedLabel,
        onChange: ({ target }) => {
          const { value } = target;
          onSearch(value, value.length >= minQueryLength);
        }
      }
    ),
    resetButton && selectedValue && /* @__PURE__ */ React7.createElement(
      "button",
      {
        type: "button",
        className: "form-input-reset absolute z-10 right-2.5 inset-y-0 my-auto h-5 px-0.5",
        onClick: () => {
          onChange(null);
        }
      },
      /* @__PURE__ */ React7.createElement(
        XMarkIcon3,
        {
          className: "h-4 w-4",
          "aria-hidden": "true"
        }
      )
    ),
    /* @__PURE__ */ React7.createElement(
      Transition3,
      {
        as: Fragment3,
        leave: "transition ease-in duration-100",
        leaveFrom: "opacity-100",
        leaveTo: "opacity-0",
        afterLeave: () => {
          onSearch("", false);
        }
      },
      /* @__PURE__ */ React7.createElement(Combobox3.Options, { className: "form-input-popup absolute z-40 mt-1 w-full bg-white py-1 shadow-lg ring-1 ring-black ring-opacity-5 focus:outline-none text-sm" }, !showOptions ? /* @__PURE__ */ React7.createElement("div", { className: "relative cursor-default select-none py-2 px-4 text-secondary-700" }, isLoading ? "Loading..." : emptyMessage) : /* @__PURE__ */ React7.createElement("div", { className: "overflow-auto max-h-60" }, options.map((option) => /* @__PURE__ */ React7.createElement(
        Combobox3.Option,
        {
          key: option.label,
          className: ({ active }) => `relative cursor-default select-none py-2 pl-10 pr-4 text-secondary-800 ${active ? "bg-primary-100" : ""}`,
          value: option
        },
        ({ selected }) => /* @__PURE__ */ React7.createElement(React7.Fragment, null, /* @__PURE__ */ React7.createElement(
          "span",
          {
            title: option.label,
            className: `block truncate ${selected && selectedValue ? "font-medium text-secondary-900" : "font-normal"}`
          },
          option.label
        ), selected && selectedValue ? /* @__PURE__ */ React7.createElement("span", { className: "absolute inset-y-0 left-0 flex items-center pl-3 text-primary-600" }, /* @__PURE__ */ React7.createElement(CheckIcon3, { className: "h-5 w-5", "aria-hidden": "true" })) : null)
      ))))
    )
  );
}
var autocomplete_default = memo7(Autocomplete);

// src/route/autocomplete.tsx
function RouteAutocomplete({
  options,
  filterName,
  defaultValue = "",
  filter,
  ...rest
}) {
  const { onChange, selectedOptions, optionValues } = useRouteSelect(
    options,
    filterName,
    [defaultValue]
  );
  const [value] = optionValues;
  const selectedValue = value ? { label: value, value } : null;
  return /* @__PURE__ */ React8.createElement(
    autocomplete_default,
    {
      ...rest,
      options,
      selectedOption: selectedOptions[0] || selectedValue,
      onChange,
      filter: filter ?? optionValues.length > 0
    }
  );
}
var autocomplete_default2 = memo8(RouteAutocomplete);

// src/route/treeSelect.tsx
import React10, { memo as memo10 } from "react";

// src/treeSelect.tsx
import classNames4 from "classnames";
import React9, { Fragment as Fragment4, memo as memo9, useState as useState2, useMemo } from "react";
import { Combobox as Combobox4, Transition as Transition4 } from "@headlessui/react";
import {
  CheckIcon as CheckIcon4,
  ChevronDownIcon as ChevronDownIcon3,
  XMarkIcon as XMarkIcon4,
  MagnifyingGlassIcon as MagnifyingGlassIcon2,
  ChevronRightIcon
} from "@heroicons/react/20/solid";
import { FolderMinusIcon } from "@heroicons/react/24/outline";

// src/common/utils.ts
function getOptions(nodes) {
  const options = [];
  for (let i = 0; i < nodes.length; i++) {
    const node = nodes[i];
    if (node.children) {
      options.push(...getOptions(node.children));
    } else {
      options.push(node);
    }
  }
  return options;
}

// src/treeSelect.tsx
function getFlatTreeGroups(treeData) {
  return treeData.filter((x) => x.children).flatMap((x) => [x, ...getFlatTreeGroups(x.children)]);
}
function filterNodes(treeData, searchString) {
  const treeNodes = [];
  for (let i = 0; i < treeData.length; i++) {
    const node = treeData[i];
    if (node.label.toLowerCase().replace(/\s+/g, "").includes(searchString)) {
      treeNodes.push(node);
      continue;
    }
    if (node.children) {
      const children = filterNodes(node.children, searchString);
      if (children.length > 0) {
        treeNodes.push({
          ...node,
          children
        });
      }
    }
  }
  return treeNodes;
}
function getSelection(node, selectionSet, selectionCache) {
  if (selectionCache.has(node)) {
    return selectionCache.get(node);
  }
  for (let i = 0; i < node.children.length; i++) {
    const child = node.children[i];
    let selection;
    if (child.children) {
      selection = getSelection(child, selectionSet, selectionCache);
    } else {
      selection = selectionSet.has(child);
    }
    if (!selection) {
      selectionCache.set(node, false);
      return false;
    }
  }
  selectionCache.set(node, true);
  return true;
}
function getHasSelection(node, selectionSet, selectionCache, hasSelectionCache) {
  if (selectionCache.get(node)) {
    return true;
  }
  if (hasSelectionCache.has(node)) {
    return hasSelectionCache.get(node);
  }
  for (let i = 0; i < node.children.length; i++) {
    const child = node.children[i];
    let hasSelection;
    if (child.children) {
      hasSelection = getHasSelection(
        child,
        selectionSet,
        selectionCache,
        hasSelectionCache
      );
    } else {
      hasSelection = selectionSet.has(child);
    }
    if (hasSelection) {
      hasSelectionCache.set(node, true);
      return true;
    }
  }
  hasSelectionCache.set(node, false);
  return false;
}
function TreeGroupOption({
  node,
  ...rest
}) {
  const { selectionSet, selectionCache, hasSelectionCache, onChange } = rest;
  const selected = getSelection(node, selectionSet, selectionCache);
  const hasSelection = selected || getHasSelection(node, selectionSet, selectionCache, hasSelectionCache);
  const expanded = !rest.collapsedSet.has(node);
  return /* @__PURE__ */ React9.createElement("div", null, /* @__PURE__ */ React9.createElement(
    "div",
    {
      onClick: () => {
        if (onChange) {
          const selectionSetClone = new Set(selectionSet);
          const options = getOptions(node.children);
          if (selected) {
            options.forEach((option) => {
              selectionSetClone.delete(option);
            });
          } else {
            options.forEach((option) => {
              selectionSetClone.add(option);
            });
          }
          onChange(Array.from(selectionSetClone));
        }
      },
      className: `relative select-none py-2 pl-10 pr-10 text-secondary-800 ${onChange ? "hover:bg-primary-100" : ""}`
    },
    /* @__PURE__ */ React9.createElement(
      "span",
      {
        title: node.label,
        className: `block truncate ${hasSelection ? "font-medium text-secondary-900" : "font-normal"}`
      },
      node.label
    ),
    selected ? /* @__PURE__ */ React9.createElement("span", { className: "absolute inset-y-0 right-4 flex items-center pl-3 text-primary-600" }, /* @__PURE__ */ React9.createElement(CheckIcon4, { className: "h-5 w-5", "aria-hidden": "true" })) : null,
    /* @__PURE__ */ React9.createElement(
      "button",
      {
        type: "button",
        tabIndex: -1,
        className: "absolute inset-y-0 left-0 flex items-center pl-3",
        onClick: (e) => {
          e.stopPropagation();
          rest.onExpand(node);
        }
      },
      expanded ? /* @__PURE__ */ React9.createElement(ChevronDownIcon3, { className: "h-5 w-5", "aria-hidden": "true" }) : /* @__PURE__ */ React9.createElement(ChevronRightIcon, { className: "h-5 w-5", "aria-hidden": "true" })
    )
  ), expanded && /* @__PURE__ */ React9.createElement("div", { className: "pl-5" }, /* @__PURE__ */ React9.createElement(TreeOptions, { nodes: node.children, ...rest })));
}
function TreeOptions({
  nodes,
  ...rest
}) {
  return /* @__PURE__ */ React9.createElement(React9.Fragment, null, nodes.map((node) => {
    if (node.children) {
      return /* @__PURE__ */ React9.createElement(TreeGroupOption, { ...rest, key: node.label, node });
    }
    return /* @__PURE__ */ React9.createElement(
      Combobox4.Option,
      {
        key: node.label,
        className: ({ active }) => `relative cursor-default select-none py-2 pl-5 pr-10 text-secondary-800 ${active ? "bg-primary-100" : ""}`,
        value: node
      },
      ({ selected }) => /* @__PURE__ */ React9.createElement(React9.Fragment, null, /* @__PURE__ */ React9.createElement(
        "span",
        {
          title: node.label,
          className: `block truncate ${selected ? "font-medium text-secondary-900" : "font-normal"}`
        },
        node.label
      ), selected ? /* @__PURE__ */ React9.createElement("span", { className: "absolute inset-y-0 right-4 flex items-center pl-3 text-primary-600" }, /* @__PURE__ */ React9.createElement(CheckIcon4, { className: "h-5 w-5", "aria-hidden": "true" })) : null)
    );
  }));
}
function TreeSelect({
  className,
  treeData,
  selectedOption,
  selectedOptions,
  onChange,
  multiple,
  placeholder,
  isLoading,
  filter,
  resetButton = true
}) {
  const [collapsedSet, setCollapsedSet] = useState2(/* @__PURE__ */ new Set());
  const [searchQuery, setSearchQuery] = useState2("");
  const selectedValue = multiple ? selectedOptions : selectedOption;
  const selectedLabel = multiple ? selectedOptions?.map((x) => x.label).join(", ") : selectedOption?.label;
  const treeNodes = useMemo(() => {
    return searchQuery === "" ? treeData : filterNodes(treeData, searchQuery.toLowerCase().replace(/\s+/g, ""));
  }, [searchQuery, treeData]);
  const selectionSet = new Set(
    multiple ? selectedOptions : selectedOption ? [selectedOption] : []
  );
  const selectionCache = /* @__PURE__ */ new Map();
  const hasSelectionCache = /* @__PURE__ */ new Map();
  return /* @__PURE__ */ React9.createElement(
    Combobox4,
    {
      value: selectedValue || null,
      onChange,
      multiple,
      nullable: true,
      as: "div",
      className: classNames4("relative", className)
    },
    /* @__PURE__ */ React9.createElement(Combobox4.Button, { as: "div" }, /* @__PURE__ */ React9.createElement(
      "button",
      {
        type: "button",
        className: classNames4(
          "form-input relative w-full cursor-default pl-3 pr-10 text-left",
          filter ? "form-input-filter" : ""
        )
      },
      /* @__PURE__ */ React9.createElement(
        "span",
        {
          title: selectedLabel,
          className: classNames4(
            "block truncate",
            selectedLabel ? "" : "text-secondary-500"
          )
        },
        selectedLabel || placeholder
      ),
      (!resetButton || !selectedLabel) && /* @__PURE__ */ React9.createElement("span", { className: "pointer-events-none absolute inset-y-0 right-0 flex items-center pr-2" }, /* @__PURE__ */ React9.createElement(
        ChevronDownIcon3,
        {
          className: "form-input-icon h-5 w-5",
          "aria-hidden": "true"
        }
      ))
    )),
    resetButton && selectedLabel && /* @__PURE__ */ React9.createElement(
      "button",
      {
        type: "button",
        className: "form-input-reset absolute z-10 right-2.5 inset-y-0 my-auto h-5 px-0.5",
        onClick: () => {
          if (multiple) {
            onChange([]);
          } else {
            onChange(null);
          }
        }
      },
      /* @__PURE__ */ React9.createElement(XMarkIcon4, { className: "h-4 w-4", "aria-hidden": "true" })
    ),
    /* @__PURE__ */ React9.createElement(
      Transition4,
      {
        as: Fragment4,
        leave: "transition ease-in duration-100",
        leaveFrom: "opacity-100",
        leaveTo: "opacity-0",
        afterLeave: () => {
          setSearchQuery("");
          if (collapsedSet.size > 0) {
            setCollapsedSet(/* @__PURE__ */ new Set());
          }
        }
      },
      /* @__PURE__ */ React9.createElement(Combobox4.Options, { className: "form-input-popup absolute z-40 mt-1 w-full bg-white py-1 shadow-lg ring-1 ring-black ring-opacity-5 focus:outline-none text-sm" }, !isLoading && /* @__PURE__ */ React9.createElement("div", { className: "relative" }, /* @__PURE__ */ React9.createElement(
        MagnifyingGlassIcon2,
        {
          className: "pointer-events-none absolute top-3.5 left-4 h-5 w-5 text-secondary-400",
          "aria-hidden": "true"
        }
      ), /* @__PURE__ */ React9.createElement(
        Combobox4.Input,
        {
          type: "search",
          placeholder: "Search...",
          className: "h-12 w-full bottom-0 border-transparent pl-11 pr-11 text-secondary-800 placeholder-secondary-400 text-sm focus:border-none focus:outline-none focus:ring-0 focus:shadow-none",
          displayValue: () => searchQuery,
          onChange: (event) => {
            setSearchQuery(event.target.value);
          }
        }
      ), /* @__PURE__ */ React9.createElement(
        "button",
        {
          type: "button",
          tabIndex: -1,
          title: "Collapse All",
          className: "absolute top-4 right-5 text-secondary-400 hover:text-primary-500",
          onClick: () => {
            const allCollapsedSet = /* @__PURE__ */ new Set();
            getFlatTreeGroups(treeNodes).forEach(
              (node) => allCollapsedSet.add(node)
            );
            setCollapsedSet(allCollapsedSet);
          }
        },
        /* @__PURE__ */ React9.createElement(FolderMinusIcon, { className: "h-4 w-4", "aria-hidden": "true" })
      )), treeNodes.length === 0 || isLoading ? /* @__PURE__ */ React9.createElement("div", { className: "relative cursor-default select-none py-2 px-4 text-secondary-700" }, isLoading ? "Loading..." : "No options") : /* @__PURE__ */ React9.createElement("div", { className: "overflow-auto max-h-60" }, /* @__PURE__ */ React9.createElement(
        TreeOptions,
        {
          nodes: treeNodes,
          selectionSet,
          selectionCache,
          hasSelectionCache,
          collapsedSet,
          onExpand: (value) => {
            if (collapsedSet.has(value)) {
              collapsedSet.delete(value);
            } else {
              collapsedSet.add(value);
            }
            setCollapsedSet(new Set(collapsedSet));
          },
          onChange: multiple ? onChange : void 0
        }
      )))
    )
  );
}
var treeSelect_default = memo9(TreeSelect);

// src/route/treeSelect.tsx
function RouteTreeSelect({
  treeData,
  filterName,
  defaultValue = "",
  defaultValues = [""],
  multiple,
  filter,
  ...rest
}) {
  const { onChange, selectedOptions, optionValues } = useRouteSelect(
    getOptions(treeData),
    filterName,
    multiple ? defaultValues : [defaultValue]
  );
  if (multiple) {
    return /* @__PURE__ */ React10.createElement(
      treeSelect_default,
      {
        ...rest,
        treeData,
        selectedOptions,
        onChange,
        multiple: true,
        filter: filter ?? optionValues.length > 0
      }
    );
  }
  return /* @__PURE__ */ React10.createElement(
    treeSelect_default,
    {
      ...rest,
      treeData,
      selectedOption: selectedOptions[0] || null,
      onChange,
      filter: filter ?? optionValues.length > 0
    }
  );
}
var treeSelect_default2 = memo10(RouteTreeSelect);

// src/route/index.tsx
var route_default = select_default2;
export {
  autocomplete_default as Autocomplete,
  combobox_default as Combobox,
  autocomplete_default2 as RouteAutocomplete,
  combobox_default2 as RouteCombobox,
  searchSelect_default2 as RouteSearchSelect,
  select_default2 as RouteSelect,
  treeSelect_default2 as RouteTreeSelect,
  searchSelect_default as SearchSelect,
  select_default as Select,
  treeSelect_default as TreeSelect,
  route_default as default
};
